@@ -3,6 +3,7 @@
 import collections
 import io
 import json
+import logging
 import os
 import tempfile
 import zipfile
@@ -20,7 +21,7 @@ except ModuleNotFoundError:
     )
 
 
-_BRANCH = "rime-data-in-pycantonese-v2.5.0"
+_BRANCH = "2020.09.09"
 _URL = f"https://github.com/jacksonllee/rime-cantonese/archive/{_BRANCH}.zip"
 
 _THIS_DIR = os.path.abspath(os.path.dirname(__file__))
@@ -31,8 +32,11 @@ _CHARS_JYUTPING_FILES = (
     _DataFile("jyut6ping3.dict.yaml", "chars_to_jyutping.json"),
 )
 _CHARS_FILES = (
+    # Not yet using the "phrases" data.
     # _DataFile("jyut6ping3.phrase.dict.yaml", "phrases.json"),
-    _DataFile("jyut6ping3.maps.dict.yaml", "maps.json"),
+    # The "maps" data has the Open Data Commons Open Database License (ODbL)
+    # that has a share-alike clause -- PyCantonese can't use this data.
+    # _DataFile("jyut6ping3.maps.dict.yaml", "maps.json"),
 )
 _RESEGMENTED_FILENAME = "resegmented.txt"
 
@@ -47,9 +51,7 @@ def _download_chars_jyutping_data(yaml_filename, json_filename):
             f.write(response.content)
 
         with zipfile.ZipFile(zip_path) as zip_file:
-            data_path = os.path.join(
-                f"rime-cantonese-{_BRANCH}", yaml_filename
-            )
+            data_path = os.path.join(f"rime-cantonese-{_BRANCH}", yaml_filename)
             with zip_file.open(data_path) as data_file:
                 for line in io.TextIOWrapper(data_file, encoding="utf-8"):
                     line = line.strip()
@@ -92,7 +94,7 @@ def _download_chars_jyutping_data(yaml_filename, json_filename):
             )[0][0]
         chars_to_jyutping[chars] = jyutping
 
-    with open(os.path.join(_THIS_DIR, json_filename), "w") as f:
+    with open(os.path.join(_THIS_DIR, json_filename), "w", encoding="utf8") as f:
         json.dump(chars_to_jyutping, f, indent=4, ensure_ascii=False)
 
 
@@ -106,9 +108,7 @@ def _download_chars_data(yaml_filename, json_filename):
             f.write(response.content)
 
         with zipfile.ZipFile(zip_path) as zip_file:
-            data_path = os.path.join(
-                f"rime-cantonese-{_BRANCH}", yaml_filename
-            )
+            data_path = os.path.join(f"rime-cantonese-{_BRANCH}", yaml_filename)
             with zip_file.open(data_path) as data_file:
                 for line in io.TextIOWrapper(data_file, encoding="utf-8"):
                     line = line.strip()
@@ -122,17 +122,17 @@ def _download_chars_data(yaml_filename, json_filename):
                         continue
                     chars.append(line)
 
-    with open(os.path.join(_THIS_DIR, json_filename), "w") as f:
+    with open(os.path.join(_THIS_DIR, json_filename), "w", encoding="utf8") as f:
         json.dump(chars, f, indent=4, ensure_ascii=False)
 
 
 def _resegment_chars_jyutping_data(json_filename):
     json_path = os.path.join(_THIS_DIR, json_filename)
 
-    with open(json_path) as f:
+    with open(json_path, encoding="utf8") as f:
         chars_to_jyutping = json.load(f)
 
-    with open(os.path.join(_THIS_DIR, _RESEGMENTED_FILENAME)) as f:
+    with open(os.path.join(_THIS_DIR, _RESEGMENTED_FILENAME), encoding="utf8") as f:
         resegmented = {}
         for line in f:
             line = line.strip()
@@ -168,26 +168,28 @@ def _resegment_chars_jyutping_data(json_filename):
                         continue
 
                     new_jp_for_word = ""
-                    for _ in range(
-                        len(split_characters_with_alphanum(new_word))
-                    ):
+                    for _ in range(len(split_characters_with_alphanum(new_word))):
                         new_jp_for_word += "".join(jp_split[i])
                         i += 1
                     new_chars_to_jyutping[new_word] = new_jp_for_word
         else:
             new_chars_to_jyutping[chars] = jp
 
-    with open(json_path, "w") as f:
+    with open(json_path, "w", encoding="utf8") as f:
         json.dump(new_chars_to_jyutping, f, indent=4, ensure_ascii=False)
 
 
 def main():
     for f in _CHARS_JYUTPING_FILES:
+        logging.info("Downloading %s as %s", f.yaml_filename, f.json_filename)
         _download_chars_jyutping_data(f.yaml_filename, f.json_filename)
+        logging.info("Resegmenting %s", f.json_filename)
         _resegment_chars_jyutping_data(f.json_filename)
     for f in _CHARS_FILES:
+        logging.info("Downloading %s as %s", f.yaml_filename, f.json_filename)
         _download_chars_data(f.yaml_filename, f.json_filename)
 
 
 if __name__ == "__main__":
+    logging.basicConfig(level="INFO")
     main()
