@@ -1,7 +1,7 @@
 import unicodedata
 
 from pycantonese.jyutping.parse_jyutping import parse_jyutping
-from pycantonese.util import endswithoneof, startswithoneof
+from pycantonese.util import endswithoneof, startswithoneof, _deprecate
 
 
 ONSETS_YALE = {
@@ -54,12 +54,47 @@ CODAS_YALE = {
 }
 
 
-def jyutping2yale(jp_str, as_list=False):
-    """
-    Convert *jp_str* to Yale.
+def jyutping_to_yale(jp_str, as_list=True):
+    """Convert Jyutping romanization into Yale romanization.
 
-    :param as_list: If True (default: False), return a list of Yale strings
-        for individual syllables.
+    .. versionadded:: 3.0.0
+        This function replaces the deprecated equivalent ``jyutping2yale``.
+
+    .. versionchanged:: 3.0.0
+        ``as_list`` has its default value switched from ``False`` to ``True``,
+        so that by default the function returns a list, which is in line with
+        the other "jyutping_to_X" functions.
+
+    Parameters
+    ----------
+    jp_str : str
+        Jyutping romanization for one or multiple characters
+    as_list : bool, optional
+        If False (default is True), the output is a string with a single quote
+        ``'`` to disambiguate unclear syllable boundaries (e.g., a consonant
+        or the low-tone marker "h" being ambiguous as an onset or as
+        part of the previous syllable).
+
+    Returns
+    -------
+    list[str], or str if as_list is False
+
+    Raises
+    ------
+    ValueError
+        If the Jyutping romanization is illegal (e.g., with unrecognized
+        elements).
+
+    Examples
+    --------
+    >>> jyutping_to_yale("gwong2dung1waa2")  # 廣東話, Cantonese
+    ['gwóng', 'dūng', 'wá']
+    >>> jyutping_to_yale("gwong2dung1waa2", as_list=False)
+    'gwóngdūngwá'
+    >>>
+    >>> # 'heihauh' would be ambiguous between hei3hau6 and hei6au6.
+    >>> jyutping_to_yale("hei3hau6", as_list=False)  # 氣候, climate
+    "hei'hauh"
     """
     jp_parsed_list = parse_jyutping(jp_str)
     yale_list = []
@@ -169,7 +204,9 @@ def jyutping2yale(jp_str, as_list=False):
     #   e.g., hei3hau6 'climate' --> heihauh
     #   (middle "h" for tone in 1st syllable or being onset of 2nd syllable?)
 
-    if len(yale_list) == 1:
+    if len(yale_list) == 0:
+        return ""
+    elif len(yale_list) == 1:
         return yale_list[0]
 
     ambiguous_consonants = {"h", "p", "t", "k", "m", "n", "ng"}
@@ -226,3 +263,12 @@ def jyutping2yale(jp_str, as_list=False):
     output_str += yale_list[-1]
 
     return output_str
+
+
+@_deprecate("jyutping2yale", "jyutping_to_yale", "3.0.0", "4.0.0")
+def jyutping2yale(*args, **kwargs):
+    """Same as jyutping_to_yale.
+
+    .. deprecated:: 3.0.0
+    """
+    return jyutping_to_yale(*args, **kwargs)
