@@ -7,7 +7,7 @@ from pycantonese.word_segmentation import Segmenter
 @pytest.mark.parametrize(
     "chars, segmenter, expected",
     [
-        ("廣東話容唔容易學？", None, ["廣東話", "容", "唔容易", "學", "？"]),
+        ("廣東話容唔容易學？", None, ["廣東話", "容", "唔", "容易", "學", "？"]),
         (
             "廣東話容唔容易學？",
             Segmenter(allow={"容唔容易"}),
@@ -16,7 +16,7 @@ from pycantonese.word_segmentation import Segmenter
         (
             "廣東話容唔容易學？",
             Segmenter(disallow={"廣東話"}),
-            ["廣東", "話", "容", "唔容易", "學", "？"],
+            ["廣東", "話", "容", "唔", "容易", "學", "？"],
         ),
         (
             "廣東話容唔容易學？",
@@ -24,7 +24,10 @@ from pycantonese.word_segmentation import Segmenter
             ["廣東", "話", "容", "唔", "容易", "學", "？"],
         ),
         ("佢淨係識呃like", Segmenter(), ["佢", "淨係", "識", "呃like"]),
-        ("個course超好grade", Segmenter(), ["個", "course", "超", "好grade"]),
+        ("個course超好grade", Segmenter(), ["個", "course", "超", "好", "grade"]),
+        # Whitespace in input string has no effect.
+        ("廣東 話容唔容 易學？ ", None, ["廣東話", "容", "唔", "容易", "學", "？"]),
+        ("\n 廣東話容唔容易學？ ", None, ["廣東話", "容", "唔", "容易", "學", "？"]),
     ],
 )
 def test_segment(chars, segmenter, expected):
